package com.bonus.canteen.core.cook.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.cook.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.cook.domain.CookRecipeBindApp;
import com.bonus.canteen.core.cook.service.ICookRecipeBindAppService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 移动端菜谱绑定关系Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "移动端菜谱绑定关系接口")
@RestController
@RequestMapping("/cook_recipe_bind_app")
public class CookRecipeBindAppController extends BaseController {
    @Autowired
    private ICookRecipeBindAppService cookRecipeBindAppService;

    /**
     * 查询移动端菜谱绑定关系列表
     */
    @ApiOperation(value = "查询移动端菜谱绑定关系列表")
    //@RequiresPermissions("cook:app:list")
    @GetMapping("/list")
    public TableDataInfo list(CookRecipeBindApp cookRecipeBindApp) {
        startPage();
        List<CookRecipeBindApp> list = cookRecipeBindAppService.selectCookRecipeBindAppList(cookRecipeBindApp);
        return getDataTable(list);
    }

    /**
     * 导出移动端菜谱绑定关系列表
     */
    @ApiOperation(value = "导出移动端菜谱绑定关系列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:app:export")
    @SysLog(title = "移动端菜谱绑定关系", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出移动端菜谱绑定关系")
    @PostMapping("/export")
    public void export(HttpServletResponse response, CookRecipeBindApp cookRecipeBindApp) {
        List<CookRecipeBindApp> list = cookRecipeBindAppService.selectCookRecipeBindAppList(cookRecipeBindApp);
        ExcelUtil<CookRecipeBindApp> util = new ExcelUtil<CookRecipeBindApp>(CookRecipeBindApp.class);
        util.exportExcel(response, list, "移动端菜谱绑定关系数据");
    }

    /**
     * 获取移动端菜谱绑定关系详细信息
     */
    @ApiOperation(value = "获取移动端菜谱绑定关系详细信息")
    //@RequiresPermissions("cook:app:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(cookRecipeBindAppService.selectCookRecipeBindAppById(id));
    }

    /**
     * 新增移动端菜谱绑定关系
     */
    @ApiOperation(value = "新增移动端菜谱绑定关系")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:app:add")
    @SysLog(title = "移动端菜谱绑定关系", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增移动端菜谱绑定关系")
    @PostMapping
    public AjaxResult add(@RequestBody CookRecipeBindApp cookRecipeBindApp) {
        try {
            return toAjax(cookRecipeBindAppService.insertCookRecipeBindApp(cookRecipeBindApp));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改移动端菜谱绑定关系
     */
    @ApiOperation(value = "修改移动端菜谱绑定关系")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:app:edit")
    @SysLog(title = "移动端菜谱绑定关系", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改移动端菜谱绑定关系")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody CookRecipeBindApp cookRecipeBindApp) {
        try {
            return toAjax(cookRecipeBindAppService.updateCookRecipeBindApp(cookRecipeBindApp));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除移动端菜谱绑定关系
     */
    @ApiOperation(value = "删除移动端菜谱绑定关系")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:app:remove")
    @SysLog(title = "移动端菜谱绑定关系", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除移动端菜谱绑定关系")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(cookRecipeBindAppService.deleteCookRecipeBindAppByIds(ids));
    }
}
